@@ -1,4 +1,4 @@
-from src.mufid.do_nothing import f as do_nothing
+from mufid.do_nothing import f as do_nothing
 from os.path import exists
 from os import remove
 
